@@ -38,6 +38,8 @@ class Configuration:
         Checks and returns `COGNICEPT_ACCESS_KEY` from configuration.
     get_cognicept_api_uri():
         Checks and returns `COGNICEPT_API_URI` from configuration.
+    get_cognicept_user_api_uri():
+        Checks and returns `COGNICEPT_USER_APT_URI` from configuration.
     get_field():
         Returns single config value
     configure_ssh():
@@ -181,6 +183,18 @@ class Configuration:
         else:
             return "https://app.cognicept.systems/api/v1/"
 
+    def get_cognicept_user_api_uri(object):
+        """
+        Checks and returns `COGNICEPT_USER_API_URI` from configuration.
+
+                Returns:
+                    cognicept_user_api_uri (str): value of `COGNICEPT_USER_API_URI`, defaults to "https://app.cognicept.systems/api/v1/"
+        """
+        if "COGNICEPT_USER_API_URI" in object.config:
+            return object.config["COGNICEPT_USER_API_URI"] 
+        else:
+            return "https://app.cognicept.systems/api/v1/"
+
     def get_field(object, field_name):
         """
         Returns single config value
@@ -418,17 +432,7 @@ class Configuration:
 
         return True
 
-    def get_cognicept_user_api_uri(object):
-        """
-        Checks and returns `COGNICEPT_API_URI` from configuration.
-
-                Returns:
-                    cognicept_api_uri (str): value of `COGNICEPT_API_URI`, defaults to "https://app.cognicept.systems/api/v1/"
-        """
-        if "COGNICEPT_API_URI" in object.config:
-            return object.config["COGNICEPT_API_URI"] 
-        else:
-            return "https://app.cognicept.systems/api/v1/"
+    
     def init_config(object, args):
         """
         Initiates runtime.env file with values from Cognicept API.
